pystagram.graph_api.endpoints.hashtag_search package — pystagram 0.1 documentation

# pystagram.graph_api.endpoints.hashtag_search package

## Submodules

## pystagram.graph_api.endpoints.hashtag_search.hashtag_search module

class pystagram.graph_api.endpoints.hashtag_search.hashtag_search.HashtagSearch(graph_api: PystagramGraphApi)

  Bases: `object`

  The HashtagSearch node of the Instagram Graph API. :param graph_api: An instance of the `InstagramGraphApi` class. :type graph_api: `InstagramGraphApi`

  get(q: str, user_id: str | None = None, access_token: str | None = None)

    Get the id of an Instagram hashtag. IDs are both static and global (i.e, the ID for #bluebottle will always be 17843857450040591 for all apps and all app users). :param q: The hashtag to search for. :type q: str :param user_id: The ID of the Instagram user to get recent media from, inferred from the InstagramGraphApi instance if None, defaults to None :type user_id: str, optional :param access_token: The access token of the Instagram user, inferred from the InstagramGraphApi instance if None, defaults to None :type access_token: str, optional :return: The response from the GET /hashtag_search endpoint. :rtype: `pystagram.helpers.api_client.api_response.PystagramApiResponse`

## Module contents